package Locale::CLDR::Transformations::Any::Bopo::Latn;
# This file auto generated from Data\common\transforms\Latin-Bopomofo.xml
#	on Sun  4 Mar  1:00:41 pm GMT

use strict;
use warnings;
use version;

our $VERSION = version->declare('v0.32.0');

use v5.10.1;
use mro 'c3';
use utf8;
use if $^V ge v5.12.0, feature => 'unicode_strings';
use Types::Standard qw( Str Int HashRef ArrayRef CodeRef RegexpRef );
use Moo;

BEGIN {
	die "Transliteration requires Perl 5.18 or above"
		unless $^V ge v5.18.0;
}

no warnings 'experimental::regex_sets';
has 'transforms' => (
	is => 'ro',
	isa => ArrayRef,
	init_arg => undef,
	default => sub { [
		qr/(?^um:\G.)/,
		{
			type => 'transform',
			data => [
			],
		},
		{
			type => 'conversion',
			data => [
				{
					before  => q(),
					after   => q(),
					replace => q(˙),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ˋ),
					result  => q(4),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ˇ),
					result  => q(3),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ˊ),
					result  => q(2),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ˉ),
					result  => q(1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄒ),
					result  => q(x),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄑ),
					result  => q(q),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄐ),
					result  => q(j),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄏ),
					result  => q(h),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄎ),
					result  => q(k),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄍ),
					result  => q(g),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄌ),
					result  => q(l),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄊ),
					result  => q(t),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄉ),
					result  => q(d),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄈ),
					result  => q(f),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄆ),
					result  => q(p),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄅ),
					result  => q(b),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄋ),
					result  => q(n1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄋ),
					result  => q(n),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄇ),
					result  => q(m1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄇ),
					result  => q(m),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄜ),
					result  => q(e1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄜ),
					result  => q(e),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄛ),
					result  => q(o1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄛ),
					result  => q(o),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄚ),
					result  => q(a1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄚ),
					result  => q(a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄦ),
					result  => q(er1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄦ),
					result  => q(er),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄣ),
					result  => q(en1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄣ),
					result  => q(en),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄢ),
					result  => q(an1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄢ),
					result  => q(an),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄡ),
					result  => q(ou1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄡ),
					result  => q(ou),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄠ),
					result  => q(ao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄠ),
					result  => q(ao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄟ),
					result  => q(ei1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄟ),
					result  => q(ei),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄞ),
					result  => q(ai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄞ),
					result  => q(ai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄝ),
					result  => q(eh1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄝ),
					result  => q(eh),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄥ),
					result  => q(eng1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄥ),
					result  => q(eng),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄤ),
					result  => q(ang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄤ),
					result  => q(ang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄨ),
					result  => q(wu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄨ),
					result  => q(wu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄨㄛ),
					result  => q(wo1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄨㄛ),
					result  => q(wo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄨㄚ),
					result  => q(wa1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄨㄚ),
					result  => q(wa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄨㄣ),
					result  => q(wen1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄨㄣ),
					result  => q(wen),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄨㄢ),
					result  => q(wan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄨㄢ),
					result  => q(wan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄨㄟ),
					result  => q(wei1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄨㄟ),
					result  => q(wei),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄨㄞ),
					result  => q(wai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄨㄞ),
					result  => q(wai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄨㄥ),
					result  => q(weng1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄨㄥ),
					result  => q(weng),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄨㄤ),
					result  => q(wang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄨㄤ),
					result  => q(wang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄨㄨㄥ),
					result  => q(wong1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄨㄨㄥ),
					result  => q(wong),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄧ),
					result  => q(yi1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄧ),
					result  => q(yi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄧㄝ),
					result  => q(ye1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄧㄝ),
					result  => q(ye),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄧㄛ),
					result  => q(yo1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄧㄛ),
					result  => q(yo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄧㄚ),
					result  => q(ya1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄧㄚ),
					result  => q(ya),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄧㄣ),
					result  => q(yin1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄧㄣ),
					result  => q(yin),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄧㄢ),
					result  => q(yan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄧㄢ),
					result  => q(yan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄧㄡ),
					result  => q(you1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄧㄡ),
					result  => q(you),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄧㄠ),
					result  => q(yao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄧㄠ),
					result  => q(yao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄧㄞ),
					result  => q(yai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄧㄞ),
					result  => q(yai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄧㄥ),
					result  => q(ying1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄧㄥ),
					result  => q(ying),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄧㄤ),
					result  => q(yang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄧㄤ),
					result  => q(yang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄩ),
					result  => q(yu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄩ),
					result  => q(yu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄩㄣ),
					result  => q(yun1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄩㄣ),
					result  => q(yun),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄩㄝ),
					result  => q(yue1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄩㄝ),
					result  => q(yue),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄩㄥ),
					result  => q(yong1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄩㄥ),
					result  => q(yong),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄩㄢ),
					result  => q(yuan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄩㄢ),
					result  => q(yuan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄙ),
					result  => q(si1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄙ),
					result  => q(si),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄙㄨ),
					result  => q(su1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄙㄨ),
					result  => q(su),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄙㄜ),
					result  => q(se1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄙㄜ),
					result  => q(se),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄙㄚ),
					result  => q(sa1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄙㄚ),
					result  => q(sa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄙㄨㄣ),
					result  => q(sun1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄙㄨㄣ),
					result  => q(sun),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄙㄨㄟ),
					result  => q(sui1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄙㄨㄟ),
					result  => q(sui),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄙㄨㄛ),
					result  => q(suo1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄙㄨㄛ),
					result  => q(suo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄙㄣ),
					result  => q(sen1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄙㄣ),
					result  => q(sen),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄙㄢ),
					result  => q(san1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄙㄢ),
					result  => q(san),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄙㄡ),
					result  => q(sou1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄙㄡ),
					result  => q(sou),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄙㄠ),
					result  => q(sao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄙㄠ),
					result  => q(sao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄙㄟ),
					result  => q(sei1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄙㄟ),
					result  => q(sei),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄙㄞ),
					result  => q(sai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄙㄞ),
					result  => q(sai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄙㄨㄥ),
					result  => q(song1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄙㄨㄥ),
					result  => q(song),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄙㄨㄢ),
					result  => q(suan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄙㄨㄢ),
					result  => q(suan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄙㄥ),
					result  => q(seng1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄙㄥ),
					result  => q(seng),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄙㄤ),
					result  => q(sang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄙㄤ),
					result  => q(sang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄘ),
					result  => q(ci1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄘ),
					result  => q(ci),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄘㄨ),
					result  => q(cu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄘㄨ),
					result  => q(cu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄘㄜ),
					result  => q(ce1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄘㄜ),
					result  => q(ce),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄘㄚ),
					result  => q(ca1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄘㄚ),
					result  => q(ca),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄘㄨㄣ),
					result  => q(cun1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄘㄨㄣ),
					result  => q(cun),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄘㄨㄟ),
					result  => q(cui1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄘㄨㄟ),
					result  => q(cui),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄘㄨㄛ),
					result  => q(cuo1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄘㄨㄛ),
					result  => q(cuo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄘㄣ),
					result  => q(cen1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄘㄣ),
					result  => q(cen),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄘㄢ),
					result  => q(can1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄘㄢ),
					result  => q(can),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄘㄡ),
					result  => q(cou1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄘㄡ),
					result  => q(cou),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄘㄠ),
					result  => q(cao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄘㄠ),
					result  => q(cao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄘㄞ),
					result  => q(cai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄘㄞ),
					result  => q(cai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄘㄨㄥ),
					result  => q(cong1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄘㄨㄥ),
					result  => q(cong),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄘㄨㄢ),
					result  => q(cuan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄘㄨㄢ),
					result  => q(cuan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄘㄥ),
					result  => q(ceng1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄘㄥ),
					result  => q(ceng),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄘㄤ),
					result  => q(cang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄘㄤ),
					result  => q(cang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄗ),
					result  => q(zi1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄗ),
					result  => q(zi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄗㄨ),
					result  => q(zu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄗㄨ),
					result  => q(zu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄗㄜ),
					result  => q(ze1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄗㄜ),
					result  => q(ze),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄗㄚ),
					result  => q(za1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄗㄚ),
					result  => q(za),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄗㄨㄣ),
					result  => q(zun1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄗㄨㄣ),
					result  => q(zun),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄗㄨㄟ),
					result  => q(zui1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄗㄨㄟ),
					result  => q(zui),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄗㄨㄛ),
					result  => q(zuo1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄗㄨㄛ),
					result  => q(zuo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄗㄣ),
					result  => q(zen1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄗㄣ),
					result  => q(zen),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄗㄢ),
					result  => q(zan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄗㄢ),
					result  => q(zan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄗㄡ),
					result  => q(zou1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄗㄡ),
					result  => q(zou),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄗㄠ),
					result  => q(zao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄗㄠ),
					result  => q(zao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄗㄟ),
					result  => q(zei1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄗㄟ),
					result  => q(zei),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄗㄞ),
					result  => q(zai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄗㄞ),
					result  => q(zai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄗㄨㄥ),
					result  => q(zong1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄗㄨㄥ),
					result  => q(zong),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄗㄨㄢ),
					result  => q(zuan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄗㄨㄢ),
					result  => q(zuan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄗㄥ),
					result  => q(zeng1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄗㄥ),
					result  => q(zeng),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄗㄤ),
					result  => q(zang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄗㄤ),
					result  => q(zang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄖ),
					result  => q(ri1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄖ),
					result  => q(ri),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄖㄨ),
					result  => q(ru1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄖㄨ),
					result  => q(ru),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄖㄜ),
					result  => q(re1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄖㄜ),
					result  => q(re),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄖㄚ),
					result  => q(ra1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄖㄚ),
					result  => q(ra),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄖㄨㄣ),
					result  => q(run1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄖㄨㄣ),
					result  => q(run),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄖㄨㄟ),
					result  => q(rui1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄖㄨㄟ),
					result  => q(rui),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄖㄨㄛ),
					result  => q(ruo1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄖㄨㄛ),
					result  => q(ruo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄖㄣ),
					result  => q(ren1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄖㄣ),
					result  => q(ren),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄖㄢ),
					result  => q(ran1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄖㄢ),
					result  => q(ran),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄖㄡ),
					result  => q(rou1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄖㄡ),
					result  => q(rou),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄖㄠ),
					result  => q(rao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄖㄠ),
					result  => q(rao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄖㄨㄥ),
					result  => q(rong1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄖㄨㄥ),
					result  => q(rong),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄖㄨㄢ),
					result  => q(ruan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄖㄨㄢ),
					result  => q(ruan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄖㄥ),
					result  => q(reng1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄖㄥ),
					result  => q(reng),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄖㄤ),
					result  => q(rang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄖㄤ),
					result  => q(rang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄕ),
					result  => q(shi1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄕ),
					result  => q(shi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄕㄨ),
					result  => q(shu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄕㄨ),
					result  => q(shu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄕㄜ),
					result  => q(she1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄕㄜ),
					result  => q(she),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄕㄚ),
					result  => q(sha1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄕㄚ),
					result  => q(sha),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄕㄨㄣ),
					result  => q(shun1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄕㄨㄣ),
					result  => q(shun),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄕㄨㄟ),
					result  => q(shui1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄕㄨㄟ),
					result  => q(shui),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄕㄨㄛ),
					result  => q(shuo1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄕㄨㄛ),
					result  => q(shuo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄕㄨㄚ),
					result  => q(shua1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄕㄨㄚ),
					result  => q(shua),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄕㄣ),
					result  => q(shen1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄕㄣ),
					result  => q(shen),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄕㄢ),
					result  => q(shan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄕㄢ),
					result  => q(shan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄕㄡ),
					result  => q(shou1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄕㄡ),
					result  => q(shou),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄕㄠ),
					result  => q(shao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄕㄠ),
					result  => q(shao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄕㄟ),
					result  => q(shei1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄕㄟ),
					result  => q(shei),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄕㄞ),
					result  => q(shai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄕㄞ),
					result  => q(shai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄕㄨㄢ),
					result  => q(shuan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄕㄨㄢ),
					result  => q(shuan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄕㄨㄞ),
					result  => q(shuai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄕㄨㄞ),
					result  => q(shuai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄕㄥ),
					result  => q(sheng1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄕㄥ),
					result  => q(sheng),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄕㄤ),
					result  => q(shang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄕㄤ),
					result  => q(shang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄕㄡㄥ),
					result  => q(shong1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄕㄡㄥ),
					result  => q(shong),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄕㄨㄤ),
					result  => q(shuang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄕㄨㄤ),
					result  => q(shuang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄔ),
					result  => q(chi1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄔ),
					result  => q(chi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄔㄨ),
					result  => q(chu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄔㄨ),
					result  => q(chu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄔㄜ),
					result  => q(che1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄔㄜ),
					result  => q(che),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄔㄚ),
					result  => q(cha1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄔㄚ),
					result  => q(cha),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄔㄨㄣ),
					result  => q(chun1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄔㄨㄣ),
					result  => q(chun),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄔㄨㄟ),
					result  => q(chui1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄔㄨㄟ),
					result  => q(chui),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄔㄨㄛ),
					result  => q(chuo1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄔㄨㄛ),
					result  => q(chuo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄔㄨㄚ),
					result  => q(chua1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄔㄨㄚ),
					result  => q(chua),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄔㄣ),
					result  => q(chen1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄔㄣ),
					result  => q(chen),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄔㄢ),
					result  => q(chan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄔㄢ),
					result  => q(chan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄔㄡ),
					result  => q(chou1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄔㄡ),
					result  => q(chou),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄔㄠ),
					result  => q(chao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄔㄠ),
					result  => q(chao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄔㄞ),
					result  => q(chai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄔㄞ),
					result  => q(chai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄔㄨㄥ),
					result  => q(chong1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄔㄨㄥ),
					result  => q(chong),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄔㄨㄢ),
					result  => q(chuan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄔㄨㄢ),
					result  => q(chuan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄔㄨㄞ),
					result  => q(chuai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄔㄨㄞ),
					result  => q(chuai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄔㄥ),
					result  => q(cheng1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄔㄥ),
					result  => q(cheng),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄔㄤ),
					result  => q(chang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄔㄤ),
					result  => q(chang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄔㄨㄤ),
					result  => q(chuang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄔㄨㄤ),
					result  => q(chuang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄓ),
					result  => q(zhi1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄓ),
					result  => q(zhi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄓㄨ),
					result  => q(zhu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄓㄨ),
					result  => q(zhu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄓㄜ),
					result  => q(zhe1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄓㄜ),
					result  => q(zhe),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄓㄚ),
					result  => q(zha1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄓㄚ),
					result  => q(zha),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄓㄨㄣ),
					result  => q(zhun1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄓㄨㄣ),
					result  => q(zhun),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄓㄨㄟ),
					result  => q(zhui1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄓㄨㄟ),
					result  => q(zhui),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄓㄨㄛ),
					result  => q(zhuo1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄓㄨㄛ),
					result  => q(zhuo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄓㄨㄚ),
					result  => q(zhua1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄓㄨㄚ),
					result  => q(zhua),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄓㄣ),
					result  => q(zhen1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄓㄣ),
					result  => q(zhen),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄓㄢ),
					result  => q(zhan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄓㄢ),
					result  => q(zhan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄓㄡ),
					result  => q(zhou1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄓㄡ),
					result  => q(zhou),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄓㄠ),
					result  => q(zhao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄓㄠ),
					result  => q(zhao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄓㄟ),
					result  => q(zhei1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄓㄟ),
					result  => q(zhei),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄓㄞ),
					result  => q(zhai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄓㄞ),
					result  => q(zhai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄓㄨㄥ),
					result  => q(zhong1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄓㄨㄥ),
					result  => q(zhong),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄓㄨㄢ),
					result  => q(zhuan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄓㄨㄢ),
					result  => q(zhuan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄓㄨㄞ),
					result  => q(zhuai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄓㄨㄞ),
					result  => q(zhuai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄓㄥ),
					result  => q(zheng1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄓㄥ),
					result  => q(zheng),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄓㄤ),
					result  => q(zhang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄓㄤ),
					result  => q(zhang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄓㄨㄤ),
					result  => q(zhuang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄓㄨㄤ),
					result  => q(zhuang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄒㄩ),
					result  => q(xu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄒㄩ),
					result  => q(xu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄒㄧ),
					result  => q(xi1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄒㄧ),
					result  => q(xi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄒㄩㄣ),
					result  => q(xun1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄒㄩㄣ),
					result  => q(xun),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄒㄩㄝ),
					result  => q(xue1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄒㄩㄝ),
					result  => q(xue),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄒㄧㄣ),
					result  => q(xin1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄒㄧㄣ),
					result  => q(xin),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄒㄧㄡ),
					result  => q(xiu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄒㄧㄡ),
					result  => q(xiu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄒㄧㄝ),
					result  => q(xie1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄒㄧㄝ),
					result  => q(xie),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄒㄧㄚ),
					result  => q(xia1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄒㄧㄚ),
					result  => q(xia),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄒㄩㄢ),
					result  => q(xuan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄒㄩㄢ),
					result  => q(xuan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄒㄧㄥ),
					result  => q(xing1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄒㄧㄥ),
					result  => q(xing),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄒㄧㄢ),
					result  => q(xian1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄒㄧㄢ),
					result  => q(xian),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄒㄧㄠ),
					result  => q(xiao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄒㄧㄠ),
					result  => q(xiao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄒㄩㄥ),
					result  => q(xiong1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄒㄩㄥ),
					result  => q(xiong),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄒㄧㄤ),
					result  => q(xiang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄒㄧㄤ),
					result  => q(xiang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄑㄩ),
					result  => q(qu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄑㄩ),
					result  => q(qu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄑㄧ),
					result  => q(qi1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄑㄧ),
					result  => q(qi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄑㄩㄣ),
					result  => q(qun1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄑㄩㄣ),
					result  => q(qun),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄑㄩㄝ),
					result  => q(que1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄑㄩㄝ),
					result  => q(que),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄑㄧㄣ),
					result  => q(qin1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄑㄧㄣ),
					result  => q(qin),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄑㄧㄡ),
					result  => q(qiu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄑㄧㄡ),
					result  => q(qiu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄑㄧㄝ),
					result  => q(qie1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄑㄧㄝ),
					result  => q(qie),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄑㄧㄚ),
					result  => q(qia1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄑㄧㄚ),
					result  => q(qia),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄑㄩㄢ),
					result  => q(quan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄑㄩㄢ),
					result  => q(quan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄑㄧㄥ),
					result  => q(qing1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄑㄧㄥ),
					result  => q(qing),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄑㄧㄢ),
					result  => q(qian1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄑㄧㄢ),
					result  => q(qian),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄑㄧㄠ),
					result  => q(qiao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄑㄧㄠ),
					result  => q(qiao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄑㄩㄥ),
					result  => q(qiong1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄑㄩㄥ),
					result  => q(qiong),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄑㄧㄤ),
					result  => q(qiang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄑㄧㄤ),
					result  => q(qiang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄐㄩ),
					result  => q(ju1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄐㄩ),
					result  => q(ju),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄐㄧ),
					result  => q(ji1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄐㄧ),
					result  => q(ji),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄐㄩㄣ),
					result  => q(jun1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄐㄩㄣ),
					result  => q(jun),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄐㄩㄝ),
					result  => q(jue1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄐㄩㄝ),
					result  => q(jue),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄐㄧㄣ),
					result  => q(jin1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄐㄧㄣ),
					result  => q(jin),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄐㄧㄡ),
					result  => q(jiu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄐㄧㄡ),
					result  => q(jiu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄐㄧㄝ),
					result  => q(jie1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄐㄧㄝ),
					result  => q(jie),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄐㄧㄚ),
					result  => q(jia1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄐㄧㄚ),
					result  => q(jia),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄐㄩㄢ),
					result  => q(juan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄐㄩㄢ),
					result  => q(juan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄐㄧㄥ),
					result  => q(jing1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄐㄧㄥ),
					result  => q(jing),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄐㄧㄢ),
					result  => q(jian1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄐㄧㄢ),
					result  => q(jian),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄐㄧㄠ),
					result  => q(jiao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄐㄧㄠ),
					result  => q(jiao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄐㄩㄥ),
					result  => q(jiong1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄐㄩㄥ),
					result  => q(jiong),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄐㄧㄤ),
					result  => q(jiang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄐㄧㄤ),
					result  => q(jiang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄏㄨ),
					result  => q(hu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄏㄨ),
					result  => q(hu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄏㄜ),
					result  => q(he1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄏㄜ),
					result  => q(he),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄏㄛ),
					result  => q(ho1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄏㄛ),
					result  => q(ho),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄏㄚ),
					result  => q(ha1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄏㄚ),
					result  => q(ha),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄏㄇ),
					result  => q(hm1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄏㄇ),
					result  => q(hm),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄏㄨㄣ),
					result  => q(hun1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄏㄨㄣ),
					result  => q(hun),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄏㄨㄟ),
					result  => q(hui1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄏㄨㄟ),
					result  => q(hui),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄏㄨㄛ),
					result  => q(huo1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄏㄨㄛ),
					result  => q(huo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄏㄨㄚ),
					result  => q(hua1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄏㄨㄚ),
					result  => q(hua),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄏㄣ),
					result  => q(hen1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄏㄣ),
					result  => q(hen),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄏㄢ),
					result  => q(han1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄏㄢ),
					result  => q(han),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄏㄡ),
					result  => q(hou1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄏㄡ),
					result  => q(hou),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄏㄠ),
					result  => q(hao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄏㄠ),
					result  => q(hao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄏㄟ),
					result  => q(hei1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄏㄟ),
					result  => q(hei),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄏㄞ),
					result  => q(hai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄏㄞ),
					result  => q(hai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄏㄨㄥ),
					result  => q(hong1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄏㄨㄥ),
					result  => q(hong),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄏㄨㄢ),
					result  => q(huan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄏㄨㄢ),
					result  => q(huan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄏㄨㄞ),
					result  => q(huai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄏㄨㄞ),
					result  => q(huai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄏㄥ),
					result  => q(heng1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄏㄥ),
					result  => q(heng),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄏㄤ),
					result  => q(hang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄏㄤ),
					result  => q(hang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄏㄨㄤ),
					result  => q(huang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄏㄨㄤ),
					result  => q(huang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄎㄨ),
					result  => q(ku1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄎㄨ),
					result  => q(ku),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄎㄜ),
					result  => q(ke1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄎㄜ),
					result  => q(ke),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄎㄚ),
					result  => q(ka1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄎㄚ),
					result  => q(ka),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄎㄨㄣ),
					result  => q(kun1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄎㄨㄣ),
					result  => q(kun),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄎㄨㄟ),
					result  => q(kui1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄎㄨㄟ),
					result  => q(kui),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄎㄨㄛ),
					result  => q(kuo1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄎㄨㄛ),
					result  => q(kuo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄎㄨㄚ),
					result  => q(kua1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄎㄨㄚ),
					result  => q(kua),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄎㄣ),
					result  => q(ken1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄎㄣ),
					result  => q(ken),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄎㄢ),
					result  => q(kan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄎㄢ),
					result  => q(kan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄎㄡ),
					result  => q(kou1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄎㄡ),
					result  => q(kou),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄎㄠ),
					result  => q(kao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄎㄠ),
					result  => q(kao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄎㄞ),
					result  => q(kai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄎㄞ),
					result  => q(kai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄎㄨㄥ),
					result  => q(kong1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄎㄨㄥ),
					result  => q(kong),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄎㄨㄢ),
					result  => q(kuan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄎㄨㄢ),
					result  => q(kuan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄎㄨㄞ),
					result  => q(kuai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄎㄨㄞ),
					result  => q(kuai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄎㄥ),
					result  => q(keng1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄎㄥ),
					result  => q(keng),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄎㄤ),
					result  => q(kang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄎㄤ),
					result  => q(kang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄎㄨㄤ),
					result  => q(kuang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄎㄨㄤ),
					result  => q(kuang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄍㄨ),
					result  => q(gu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄍㄨ),
					result  => q(gu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄍㄧ),
					result  => q(gi1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄍㄧ),
					result  => q(gi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄍㄜ),
					result  => q(ge1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄍㄜ),
					result  => q(ge),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄍㄚ),
					result  => q(ga1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄍㄚ),
					result  => q(ga),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄍㄨㄣ),
					result  => q(gun1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄍㄨㄣ),
					result  => q(gun),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄍㄨㄟ),
					result  => q(gui1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄍㄨㄟ),
					result  => q(gui),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄍㄨㄛ),
					result  => q(guo1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄍㄨㄛ),
					result  => q(guo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄍㄨㄚ),
					result  => q(gua1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄍㄨㄚ),
					result  => q(gua),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄍㄣ),
					result  => q(gen1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄍㄣ),
					result  => q(gen),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄍㄢ),
					result  => q(gan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄍㄢ),
					result  => q(gan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄍㄡ),
					result  => q(gou1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄍㄡ),
					result  => q(gou),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄍㄠ),
					result  => q(gao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄍㄠ),
					result  => q(gao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄍㄟ),
					result  => q(gei1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄍㄟ),
					result  => q(gei),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄍㄞ),
					result  => q(gai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄍㄞ),
					result  => q(gai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄍㄨㄥ),
					result  => q(gong1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄍㄨㄥ),
					result  => q(gong),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄍㄨㄢ),
					result  => q(guan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄍㄨㄢ),
					result  => q(guan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄍㄨㄞ),
					result  => q(guai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄍㄨㄞ),
					result  => q(guai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄍㄥ),
					result  => q(geng1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄍㄥ),
					result  => q(geng),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄍㄤ),
					result  => q(gang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄍㄤ),
					result  => q(gang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄍㄨㄤ),
					result  => q(guang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄍㄨㄤ),
					result  => q(guang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄌㄩ),
					result  => q(lü1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄌㄩ),
					result  => q(lü),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄌㄨ),
					result  => q(lu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄌㄨ),
					result  => q(lu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄌㄧ),
					result  => q(li1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄌㄧ),
					result  => q(li),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄌㄜ),
					result  => q(le1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄌㄜ),
					result  => q(le),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄌㄛ),
					result  => q(lo1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄌㄛ),
					result  => q(lo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄌㄚ),
					result  => q(la1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄌㄚ),
					result  => q(la),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄌㄩㄝ),
					result  => q(lüe1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄌㄩㄝ),
					result  => q(lüe),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄌㄨㄣ),
					result  => q(lun1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄌㄨㄣ),
					result  => q(lun),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄌㄨㄛ),
					result  => q(luo1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄌㄨㄛ),
					result  => q(luo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄌㄧㄣ),
					result  => q(lin1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄌㄧㄣ),
					result  => q(lin),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄌㄧㄡ),
					result  => q(liu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄌㄧㄡ),
					result  => q(liu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄌㄧㄝ),
					result  => q(lie1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄌㄧㄝ),
					result  => q(lie),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄌㄧㄚ),
					result  => q(lia1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄌㄧㄚ),
					result  => q(lia),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄌㄢ),
					result  => q(lan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄌㄢ),
					result  => q(lan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄌㄡ),
					result  => q(lou1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄌㄡ),
					result  => q(lou),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄌㄠ),
					result  => q(lao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄌㄠ),
					result  => q(lao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄌㄟ),
					result  => q(lei1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄌㄟ),
					result  => q(lei),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄌㄞ),
					result  => q(lai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄌㄞ),
					result  => q(lai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄌㄩㄢ),
					result  => q(lüan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄌㄩㄢ),
					result  => q(lüan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄌㄨㄥ),
					result  => q(long1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄌㄨㄥ),
					result  => q(long),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄌㄨㄢ),
					result  => q(luan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄌㄨㄢ),
					result  => q(luan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄌㄧㄥ),
					result  => q(ling1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄌㄧㄥ),
					result  => q(ling),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄌㄧㄢ),
					result  => q(lian1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄌㄧㄢ),
					result  => q(lian),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄌㄧㄠ),
					result  => q(liao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄌㄧㄠ),
					result  => q(liao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄌㄥ),
					result  => q(leng1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄌㄥ),
					result  => q(leng),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄌㄤ),
					result  => q(lang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄌㄤ),
					result  => q(lang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄌㄧㄤ),
					result  => q(liang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄌㄧㄤ),
					result  => q(liang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄋㄩ),
					result  => q(nü1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄋㄩ),
					result  => q(nü),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄋㄨ),
					result  => q(nu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄋㄨ),
					result  => q(nu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄋㄧ),
					result  => q(ni1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄋㄧ),
					result  => q(ni),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄋㄜ),
					result  => q(ne1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄋㄜ),
					result  => q(ne),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄋㄚ),
					result  => q(na1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄋㄚ),
					result  => q(na),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄋㄩㄝ),
					result  => q(nüe1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄋㄩㄝ),
					result  => q(nüe),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄋㄨㄣ),
					result  => q(nun1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄋㄨㄣ),
					result  => q(nun),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄋㄨㄛ),
					result  => q(nuo1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄋㄨㄛ),
					result  => q(nuo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄋㄧㄣ),
					result  => q(nin1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄋㄧㄣ),
					result  => q(nin),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄋㄧㄡ),
					result  => q(niu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄋㄧㄡ),
					result  => q(niu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄋㄧㄝ),
					result  => q(nie1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄋㄧㄝ),
					result  => q(nie),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄋㄧㄚ),
					result  => q(nia1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄋㄧㄚ),
					result  => q(nia),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄋㄣ),
					result  => q(nen1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄋㄣ),
					result  => q(nen),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄋㄢ),
					result  => q(nan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄋㄢ),
					result  => q(nan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄋㄡ),
					result  => q(nou1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄋㄡ),
					result  => q(nou),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄋㄠ),
					result  => q(nao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄋㄠ),
					result  => q(nao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄋㄟ),
					result  => q(nei1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄋㄟ),
					result  => q(nei),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄋㄞ),
					result  => q(nai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄋㄞ),
					result  => q(nai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄋㄨㄥ),
					result  => q(nong1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄋㄨㄥ),
					result  => q(nong),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄋㄨㄢ),
					result  => q(nuan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄋㄨㄢ),
					result  => q(nuan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄋㄧㄥ),
					result  => q(ning1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄋㄧㄥ),
					result  => q(ning),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄋㄧㄢ),
					result  => q(nian1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄋㄧㄢ),
					result  => q(nian),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄋㄧㄠ),
					result  => q(niao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄋㄧㄠ),
					result  => q(niao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄋㄥ),
					result  => q(neng1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄋㄥ),
					result  => q(neng),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄋㄤ),
					result  => q(nang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄋㄤ),
					result  => q(nang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄋㄧㄤ),
					result  => q(niang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄋㄧㄤ),
					result  => q(niang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄊㄨ),
					result  => q(tu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄊㄨ),
					result  => q(tu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄊㄧ),
					result  => q(ti1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄊㄧ),
					result  => q(ti),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄊㄜ),
					result  => q(te1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄊㄜ),
					result  => q(te),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄊㄚ),
					result  => q(ta1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄊㄚ),
					result  => q(ta),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄊㄨㄣ),
					result  => q(tun1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄊㄨㄣ),
					result  => q(tun),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄊㄨㄟ),
					result  => q(tui1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄊㄨㄟ),
					result  => q(tui),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄊㄨㄛ),
					result  => q(tuo1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄊㄨㄛ),
					result  => q(tuo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄊㄧㄝ),
					result  => q(tie1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄊㄧㄝ),
					result  => q(tie),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄊㄢ),
					result  => q(tan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄊㄢ),
					result  => q(tan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄊㄡ),
					result  => q(tou1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄊㄡ),
					result  => q(tou),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄊㄠ),
					result  => q(tao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄊㄠ),
					result  => q(tao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄊㄞ),
					result  => q(tai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄊㄞ),
					result  => q(tai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄊㄨㄥ),
					result  => q(tong1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄊㄨㄥ),
					result  => q(tong),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄊㄨㄢ),
					result  => q(tuan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄊㄨㄢ),
					result  => q(tuan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄊㄧㄥ),
					result  => q(ting1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄊㄧㄥ),
					result  => q(ting),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄊㄧㄢ),
					result  => q(tian1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄊㄧㄢ),
					result  => q(tian),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄊㄧㄠ),
					result  => q(tiao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄊㄧㄠ),
					result  => q(tiao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄊㄥ),
					result  => q(teng1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄊㄥ),
					result  => q(teng),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄊㄤ),
					result  => q(tang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄊㄤ),
					result  => q(tang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄉㄨ),
					result  => q(du1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄉㄨ),
					result  => q(du),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄉㄧ),
					result  => q(di1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄉㄧ),
					result  => q(di),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄉㄜ),
					result  => q(de1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄉㄜ),
					result  => q(de),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄉㄚ),
					result  => q(da1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄉㄚ),
					result  => q(da),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄉㄨㄣ),
					result  => q(dun1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄉㄨㄣ),
					result  => q(dun),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄉㄨㄟ),
					result  => q(dui1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄉㄨㄟ),
					result  => q(dui),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄉㄨㄛ),
					result  => q(duo1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄉㄨㄛ),
					result  => q(duo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄉㄧㄣ),
					result  => q(din1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄉㄧㄣ),
					result  => q(din),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄉㄧㄡ),
					result  => q(diu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄉㄧㄡ),
					result  => q(diu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄉㄧㄝ),
					result  => q(die1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄉㄧㄝ),
					result  => q(die),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄉㄧㄚ),
					result  => q(dia1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄉㄧㄚ),
					result  => q(dia),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄉㄣ),
					result  => q(den1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄉㄣ),
					result  => q(den),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄉㄢ),
					result  => q(dan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄉㄢ),
					result  => q(dan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄉㄡ),
					result  => q(dou1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄉㄡ),
					result  => q(dou),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄉㄠ),
					result  => q(dao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄉㄠ),
					result  => q(dao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄉㄟ),
					result  => q(dei1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄉㄟ),
					result  => q(dei),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄉㄞ),
					result  => q(dai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄉㄞ),
					result  => q(dai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄉㄨㄥ),
					result  => q(dong1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄉㄨㄥ),
					result  => q(dong),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄉㄨㄢ),
					result  => q(duan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄉㄨㄢ),
					result  => q(duan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄉㄧㄥ),
					result  => q(ding1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄉㄧㄥ),
					result  => q(ding),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄉㄧㄢ),
					result  => q(dian1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄉㄧㄢ),
					result  => q(dian),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄉㄧㄠ),
					result  => q(diao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄉㄧㄠ),
					result  => q(diao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄉㄥ),
					result  => q(deng1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄉㄥ),
					result  => q(deng),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄉㄤ),
					result  => q(dang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄉㄤ),
					result  => q(dang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄉㄧㄤ),
					result  => q(diang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄉㄧㄤ),
					result  => q(diang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄈㄨ),
					result  => q(fu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄈㄨ),
					result  => q(fu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄈㄛ),
					result  => q(fo1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄈㄛ),
					result  => q(fo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄈㄚ),
					result  => q(fa1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄈㄚ),
					result  => q(fa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄈㄣ),
					result  => q(fen1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄈㄣ),
					result  => q(fen),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄈㄢ),
					result  => q(fan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄈㄢ),
					result  => q(fan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄈㄡ),
					result  => q(fou1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄈㄡ),
					result  => q(fou),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄈㄟ),
					result  => q(fei1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄈㄟ),
					result  => q(fei),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄈㄧㄠ),
					result  => q(fiao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄈㄧㄠ),
					result  => q(fiao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄈㄥ),
					result  => q(feng1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄈㄥ),
					result  => q(feng),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄈㄤ),
					result  => q(fang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄈㄤ),
					result  => q(fang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄇㄨ),
					result  => q(mu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄇㄨ),
					result  => q(mu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄇㄧ),
					result  => q(mi1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄇㄧ),
					result  => q(mi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄇㄜ),
					result  => q(me1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄇㄜ),
					result  => q(me),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄇㄛ),
					result  => q(mo1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄇㄛ),
					result  => q(mo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄇㄚ),
					result  => q(ma1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄇㄚ),
					result  => q(ma),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄇㄧㄣ),
					result  => q(min1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄇㄧㄣ),
					result  => q(min),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄇㄧㄡ),
					result  => q(miu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄇㄧㄡ),
					result  => q(miu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄇㄧㄝ),
					result  => q(mie1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄇㄧㄝ),
					result  => q(mie),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄇㄣ),
					result  => q(men1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄇㄣ),
					result  => q(men),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄇㄢ),
					result  => q(man1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄇㄢ),
					result  => q(man),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄇㄡ),
					result  => q(mou1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄇㄡ),
					result  => q(mou),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄇㄠ),
					result  => q(mao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄇㄠ),
					result  => q(mao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄇㄟ),
					result  => q(mei1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄇㄟ),
					result  => q(mei),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄇㄞ),
					result  => q(mai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄇㄞ),
					result  => q(mai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄇㄧㄥ),
					result  => q(ming1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄇㄧㄥ),
					result  => q(ming),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄇㄧㄢ),
					result  => q(mian1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄇㄧㄢ),
					result  => q(mian),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄇㄧㄠ),
					result  => q(miao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄇㄧㄠ),
					result  => q(miao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄇㄥ),
					result  => q(meng1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄇㄥ),
					result  => q(meng),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄇㄤ),
					result  => q(mang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄇㄤ),
					result  => q(mang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄆㄨ),
					result  => q(pu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄆㄨ),
					result  => q(pu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄆㄧ),
					result  => q(pi1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄆㄧ),
					result  => q(pi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄆㄛ),
					result  => q(po1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄆㄛ),
					result  => q(po),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄆㄚ),
					result  => q(pa1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄆㄚ),
					result  => q(pa),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄆㄧㄣ),
					result  => q(pin1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄆㄧㄣ),
					result  => q(pin),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄆㄧㄝ),
					result  => q(pie1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄆㄧㄝ),
					result  => q(pie),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄆㄣ),
					result  => q(pen1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄆㄣ),
					result  => q(pen),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄆㄢ),
					result  => q(pan1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄆㄢ),
					result  => q(pan),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄆㄡ),
					result  => q(pou1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄆㄡ),
					result  => q(pou),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄆㄠ),
					result  => q(pao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄆㄠ),
					result  => q(pao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄆㄟ),
					result  => q(pei1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄆㄟ),
					result  => q(pei),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄆㄞ),
					result  => q(pai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄆㄞ),
					result  => q(pai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄆㄧㄥ),
					result  => q(ping1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄆㄧㄥ),
					result  => q(ping),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄆㄧㄢ),
					result  => q(pian1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄆㄧㄢ),
					result  => q(pian),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄆㄧㄠ),
					result  => q(piao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄆㄧㄠ),
					result  => q(piao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄆㄥ),
					result  => q(peng1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄆㄥ),
					result  => q(peng),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄆㄤ),
					result  => q(pang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄆㄤ),
					result  => q(pang),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄅㄨ),
					result  => q(bu1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄅㄨ),
					result  => q(bu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄅㄧ),
					result  => q(bi1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄅㄧ),
					result  => q(bi),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄅㄛ),
					result  => q(bo1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄅㄛ),
					result  => q(bo),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄅㄚ),
					result  => q(ba1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄅㄚ),
					result  => q(ba),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄅㄨㄣ),
					result  => q(bun1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄅㄨㄣ),
					result  => q(bun),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄅㄧㄣ),
					result  => q(bin1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄅㄧㄣ),
					result  => q(bin),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄅㄧㄝ),
					result  => q(bie1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄅㄧㄝ),
					result  => q(bie),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄅㄣ),
					result  => q(ben1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄅㄣ),
					result  => q(ben),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄅㄢ),
					result  => q(ban1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄅㄢ),
					result  => q(ban),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄅㄠ),
					result  => q(bao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄅㄠ),
					result  => q(bao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄅㄟ),
					result  => q(bei1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄅㄟ),
					result  => q(bei),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄅㄞ),
					result  => q(bai1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄅㄞ),
					result  => q(bai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄅㄧㄥ),
					result  => q(bing1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄅㄧㄥ),
					result  => q(bing),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄅㄧㄢ),
					result  => q(bian1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄅㄧㄢ),
					result  => q(bian),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄅㄧㄠ),
					result  => q(biao1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄅㄧㄠ),
					result  => q(biao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄅㄥ),
					result  => q(beng1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄅㄥ),
					result  => q(beng),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ㄅㄤ),
					result  => q(bang1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q([ˉˊˇˋ˙]),
					replace => q(ㄅㄤ),
					result  => q(bang),
					revisit => 0,
				},
			],
		},
		{
			type => 'transform',
			data => [
				{
					from => q(NumericPinyin),
					to => q(Latin),
				},
			]
		},
	] },
);

no Moo;

1;

# vim: tabstop=4
